import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { ListStatementsRequest, ListStatementsResponse } from "../models/models_0";
import { RedshiftDataClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../RedshiftDataClient";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link ListStatementsCommand}.
 */
export interface ListStatementsCommandInput extends ListStatementsRequest {
}
/**
 * @public
 *
 * The output of {@link ListStatementsCommand}.
 */
export interface ListStatementsCommandOutput extends ListStatementsResponse, __MetadataBearer {
}
declare const ListStatementsCommand_base: {
    new (input: ListStatementsCommandInput): import("@smithy/smithy-client").CommandImpl<ListStatementsCommandInput, ListStatementsCommandOutput, RedshiftDataClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (...[input]: [] | [ListStatementsCommandInput]): import("@smithy/smithy-client").CommandImpl<ListStatementsCommandInput, ListStatementsCommandOutput, RedshiftDataClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>List of SQL statements. By default, only finished statements are shown.
 *         A token is returned to page through the statement list. </p>
 *          <p>When you use identity-enhanced role sessions to list statements, you must provide either the
 *      <code>cluster-identifier</code> or <code>workgroup-name</code> parameter. This ensures that the IdC user
 *      can only access the Amazon Redshift IdC applications they are assigned. For more information, see
 *        <a href="https://docs.aws.amazon.com/singlesignon/latest/userguide/trustedidentitypropagation-overview.html">
 *          Trusted identity propagation overview</a>.</p>
 *          <p>For more information about the Amazon Redshift Data API and CLI usage examples, see
 *        <a href="https://docs.aws.amazon.com/redshift/latest/mgmt/data-api.html">Using the Amazon Redshift Data API</a> in the
 *        <i>Amazon Redshift Management Guide</i>. </p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { RedshiftDataClient, ListStatementsCommand } from "@aws-sdk/client-redshift-data"; // ES Modules import
 * // const { RedshiftDataClient, ListStatementsCommand } = require("@aws-sdk/client-redshift-data"); // CommonJS import
 * const client = new RedshiftDataClient(config);
 * const input = { // ListStatementsRequest
 *   NextToken: "STRING_VALUE",
 *   MaxResults: Number("int"),
 *   StatementName: "STRING_VALUE",
 *   Status: "STRING_VALUE",
 *   RoleLevel: true || false,
 *   Database: "STRING_VALUE",
 *   ClusterIdentifier: "STRING_VALUE",
 *   WorkgroupName: "STRING_VALUE",
 * };
 * const command = new ListStatementsCommand(input);
 * const response = await client.send(command);
 * // { // ListStatementsResponse
 * //   Statements: [ // StatementList // required
 * //     { // StatementData
 * //       Id: "STRING_VALUE", // required
 * //       QueryString: "STRING_VALUE",
 * //       QueryStrings: [ // StatementStringList
 * //         "STRING_VALUE",
 * //       ],
 * //       SecretArn: "STRING_VALUE",
 * //       Status: "STRING_VALUE",
 * //       StatementName: "STRING_VALUE",
 * //       CreatedAt: new Date("TIMESTAMP"),
 * //       UpdatedAt: new Date("TIMESTAMP"),
 * //       QueryParameters: [ // SqlParametersList
 * //         { // SqlParameter
 * //           name: "STRING_VALUE", // required
 * //           value: "STRING_VALUE", // required
 * //         },
 * //       ],
 * //       IsBatchStatement: true || false,
 * //       ResultFormat: "STRING_VALUE",
 * //       SessionId: "STRING_VALUE",
 * //     },
 * //   ],
 * //   NextToken: "STRING_VALUE",
 * // };
 *
 * ```
 *
 * @param ListStatementsCommandInput - {@link ListStatementsCommandInput}
 * @returns {@link ListStatementsCommandOutput}
 * @see {@link ListStatementsCommandInput} for command's `input` shape.
 * @see {@link ListStatementsCommandOutput} for command's `response` shape.
 * @see {@link RedshiftDataClientResolvedConfig | config} for RedshiftDataClient's `config` shape.
 *
 * @throws {@link InternalServerException} (server fault)
 *  <p>The Amazon Redshift Data API operation failed due to invalid input. </p>
 *
 * @throws {@link ValidationException} (client fault)
 *  <p>The Amazon Redshift Data API operation failed due to invalid input. </p>
 *
 * @throws {@link RedshiftDataServiceException}
 * <p>Base exception class for all service exceptions from RedshiftData service.</p>
 *
 *
 * @public
 */
export declare class ListStatementsCommand extends ListStatementsCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: ListStatementsRequest;
            output: ListStatementsResponse;
        };
        sdk: {
            input: ListStatementsCommandInput;
            output: ListStatementsCommandOutput;
        };
    };
}
